
# q-expansion of newform 1305.4.a.m, downloaded from the LMFDB on 05 February 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1305
weight = 4
poly_data = [638, -767, -167, 329, 18, -35, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0], 1], [[-10, -1, 1, 0, 0, 0, 0], 1], [[-94, -131, 128, 67, -23, -4, 1], 20], [[-1262, 157, 814, 1, -99, -2, 3], 20], [[744, -304, -363, 43, 38, -1, -1], 10], [[-8898, 3183, 4946, -381, -581, 2, 17], 40]]

hecke_ring_character_values = None
aps_data = [[0, 1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0], [5, 0, 0, 0, 0, 0, 0], [-6, 0, -1, 0, 1, -1, -1], [2, -8, -1, 0, 1, -5, -1], [-18, -4, -4, -2, -1, -2, 3], [-1, -12, -1, -1, -3, 5, -2], [-22, 8, 1, 2, -6, 11, 0], [10, 8, -1, 0, 2, 13, 8], [29, 0, 0, 0, 0, 0, 0], [-69, 2, 12, 7, 8, 2, 1], [-138, -26, 4, 0, -20, 0, -10], [105, -14, -17, 5, -18, -9, 7], [-76, 24, -6, -2, 6, -26, 14], [33, -18, -11, 21, -9, 19, 6], [-74, -40, -6, -18, 30, -10, -2], [32, 72, 10, -10, 20, -30, -20], [-143, -66, 51, 11, -34, -1, -5], [-239, -118, -36, -11, 45, -8, 24], [172, 64, 40, 14, 10, -8, -34], [-154, 90, -12, -24, 28, 96, 10], [45, 22, 26, 11, 12, -32, -13], [-87, 114, 6, -5, 8, 92, 7], [-12, 112, 42, 12, -7, -32, 11], [-482, -126, 30, -6, 44, 22, -14], [535, -30, 45, -35, -59, 35, 0], [-461, -10, 40, -77, 28, -22, -23], [-107, 310, 58, 1, 10, 60, -15], [-211, -114, -57, -23, 13, 93, -62], [181, -168, 23, 1, -107, -3, 24], [-452, -284, 96, 32, -14, 4, -10], [230, -384, -31, 80, 101, -171, 23], [-132, 138, -22, -46, -18, -26, 26], [-131, 142, -5, 113, -57, -63, 54], [-166, -276, 20, 30, -20, -60, 100], [-924, -376, -46, 12, 84, -2, 64], [-64, -318, -38, -24, -120, -130, 96], [-1192, 104, -112, 50, -84, 84, -80], [-862, 432, 11, 144, -34, -111, -12], [300, 40, 154, 30, -50, 150, -20], [-1086, 196, 166, 16, 10, -58, 16], [-503, 338, 121, 113, 199, -45, -92], [-432, 132, 247, -38, -18, 93, -102], [-1160, 158, 88, 146, -34, 20, -78], [-584, 480, -98, -66, -52, -178, 46], [-679, 158, -113, -75, -11, -111, 4], [644, 476, 49, -154, -220, 243, 16], [-1852, 196, -73, 2, -73, -69, -197], [-999, 262, 152, 15, 220, -446, -161], [-211, -26, -259, -115, 138, 17, 19], [-935, 326, -131, -91, 334, -15, 103], [-1492, -344, -66, 40, -198, 278, -178], [939, 134, 197, -253, -99, 103, 4], [-422, -740, -261, -164, 125, -165, -201], [-935, -6, -377, 63, -206, 51, 103], [-478, -696, -262, -106, 136, -38, 18], [-1545, 726, 365, -55, -3, 239, 12], [-1347, 170, 116, 149, 158, -510, -39], [684, 608, 538, 232, 77, -76, 43], [54, -28, 188, -98, 42, 96, 366], [-198, 464, -123, 132, 334, -125, -64], [3511, 248, -291, 163, -97, 115, 56], [-1150, -324, 92, 294, -172, 96, -354], [2275, -14, 264, 83, -73, -508, -244], [-651, 1646, 7, -129, 57, -435, 258], [-293, -696, -425, 167, 127, 205, 340], [-1504, -784, -447, 58, 568, -373, 100], [504, 346, 210, 130, -262, 450, -22], [11, -774, -522, -129, 72, 368, -87], [-790, 644, -442, -328, 144, 342, 88], [1817, 182, 109, -163, -358, 193, -133], [-880, 1040, 293, 178, -450, 239, -170], [-1628, 380, -108, -52, -132, -788, -192], [-1713, 1414, 565, 71, -194, 597, 293], [1498, 1152, 19, 32, -596, 725, 178], [-894, -800, -1089, -154, -358, 397, 264], [2959, 1202, 573, 37, 227, 415, -138], [-2975, 318, -521, -47, -234, 459, 663], [468, -1512, 428, 224, -310, -388, -240], [164, -1028, 384, 544, -350, 340, -400], [4382, -156, 624, -22, 422, -808, -48], [2099, 970, -395, 481, -432, 685, 123], [1734, 324, -306, 206, 560, -98, 546], [-4622, 1370, -424, -218, 652, -68, 438], [-3681, 558, -277, -445, 693, -611, 170], [-3031, -1386, 59, -691, 613, -59, -480], [728, -276, -310, -100, -393, -52, 489], [2871, 1414, 169, 53, -367, -153, 20], [-1788, -2664, -170, -138, -8, 470, -18], [-5068, 864, -91, 322, 75, -383, -557], [1848, -700, 406, 704, -1072, -138, -544], [-2896, -1188, 187, -434, 550, 25, -102], [-4659, 158, -588, -295, -492, -350, 235], [-1963, -914, -342, 429, 604, -188, -541], [7487, -434, 303, 211, -173, 213, -372], [-5401, 1550, 65, -41, 315, -457, -288], [6104, 328, -396, -788, 626, -516, 428], [1954, 1284, -572, -722, -732, 756, 444], [3389, -1402, 640, 77, 371, 92, 222], [1405, -254, 17, -883, 466, 157, 423], [-2849, -2762, 376, 171, 479, -256, -500], [-4280, 3412, 560, -40, -582, 2036, -248], [-7131, 322, 643, 597, 45, -1055, 40], [2644, 1712, 290, 1184, -567, 532, -301], [4878, -1896, -338, -306, 148, -1190, -250], [-4342, 1466, -838, 596, -616, 242, 522], [-3867, -754, 208, -597, 484, 210, -37], [2673, -154, 1675, 303, 1036, 371, -611], [-2427, -1754, -1228, -47, -625, 16, 386], [10, -1916, -1008, -344, -820, 1408, 288], [-11342, -1656, -294, 232, 1020, -818, -214], [476, 1432, 282, 308, -921, -120, -331], [-5436, 3826, -840, 250, -222, -144, 982], [8600, -1236, 87, 218, -244, 85, -636], [5625, -3170, -317, -151, 893, -435, -396], [1058, -984, -1228, 398, -747, -1658, -83], [7839, -1490, 900, 87, -903, -716, 406], [-13522, 2800, -843, -118, -124, 323, 742], [751, -2120, 1125, 259, 719, -857, -16], [-7692, 3980, -137, -554, -625, 895, 987], [-1495, -938, -911, 181, -505, 2271, 960], [15957, -2270, -801, -45, 705, -1919, -98], [3977, 2308, 583, -191, 433, 49, -1408], [-7087, -3814, 44, -63, -952, 46, -769], [3931, -2266, -1381, -585, 353, -1435, -514], [-8198, 516, 868, -342, 432, 1244, 232], [-7136, 1992, -1976, 338, 516, -776, 526], [2244, 824, -2056, 314, 1194, -1024, 518], [8194, 2424, 1354, 258, -640, -726, -602], [1570, -3682, 1182, 54, 1810, -1422, -944], [11434, 1576, 1237, 762, -632, 739, 310], [-11331, 570, 299, -663, -537, -871, 46], [-8173, 2994, 10, 175, -1068, 1260, 661], [354, -3506, 1190, -80, -444, -194, 434], [-2262, -1684, 2068, -202, 1314, 1304, 98], [3420, -1584, -1624, -504, -1540, -208, 374], [1374, 1262, -1260, -224, 1942, -1072, 324], [-17282, -780, -265, -320, 1310, 1161, -296], [11946, 3726, -1290, 972, 618, 838, 444], [3626, -4540, -1792, 350, -873, -246, 331], [4257, -1558, -1949, -747, 205, -1231, -308], [4922, -984, -762, 60, 920, -2550, -308], [4474, 3160, 6, 340, -534, -1554, -376], [-16998, 1324, -1382, 454, -1568, 290, -502], [-8005, 1374, 439, 3, 724, -33, -781], [9209, 2402, 554, -1439, 735, 1430, -1110], [-7314, 854, 950, 518, -10, 122, -704], [3701, -22, 3517, 125, 866, 217, -21], [-11538, 2380, 1959, -490, -406, 2733, -200], [4036, -1580, -187, 1124, -416, -793, 364], [-12075, -26, 263, 553, -590, -1105, -1377], [2320, 1984, 1822, 1804, 861, 20, -365], [14080, 816, -533, 770, -2650, -223, 494], [1825, -3710, -1229, -1227, 2045, -3883, 120], [6516, 1152, 1682, 194, 664, 3410, -168], [-13925, 2678, -1506, -549, -1225, 1778, 1280], [6111, -3358, -11, -653, -719, 1623, 154], [13284, -6196, 2090, -294, 780, -134, -1602], [-1671, -5854, 911, 1255, -685, -2199, -1020], [2294, 4068, 516, -586, -1940, 532, -504], [-9437, 2458, 833, -17, -661, -1201, -1716], [8473, 2382, -2005, -57, 926, -193, -1521], [-8270, -248, 3754, -56, -944, -1546, 6], [-9, 4918, 2194, 479, -472, -2396, -567], [-14633, 4934, 35, 367, 792, -637, -1321], [-6092, -1948, 34, 900, 1264, -1634, 472], [1605, 3426, 787, -1311, 1303, 997, 806], [-25266, 470, -318, -1616, 1916, -886, 422], [-753, -3114, 569, 1727, -823, -1813, 196], [2799, -284, 299, -41, 1275, -7, 1168], [8932, -1472, -2638, 924, 268, 1758, -40], [4887, 7586, -1729, -73, 523, 1741, -842], [-17010, -428, -1986, 934, 860, -2306, 806], [242, -2146, -3834, -1176, 648, -242, 150], [-6506, 3956, 576, 1342, 944, -932, -1270], [1532, 5416, 1806, 184, 764, 3118, 234], [16477, 6010, -2123, 361, -279, 2215, 1116], [3265, 2570, 1647, 987, -1463, 3625, -34], [7380, 3052, -962, -116, -338, 2062, 2090], [-12585, 2110, 981, -669, 821, 2687, -964], [-24460, 6668, 2418, -1658, 874, 2310, 142], [-28202, -2924, -3347, -1136, 1381, -627, 243], [2272, -5392, -946, -1480, 1551, 232, -335], [-19445, -5610, 111, -789, 288, -1073, 1427], [-12318, -7964, 113, 830, -1968, 1279, 962], [-12998, -6868, -1252, -1750, 1332, -1708, -148], [2128, -2786, 3768, -48, 322, 2180, -530], [8258, -1388, 1806, -206, 410, 482, -1916], [-18862, -2496, -2370, -1622, 0, 870, 272], [-20524, 3552, 1282, -1710, -952, 554, 84], [-2213, -1602, 1433, 545, 255, -2713, 1230], [-10729, -926, 2707, 1407, 1555, 1917, 120], [8568, 4480, 2963, 1218, 1854, 1693, -374], [-4225, 726, -7, 2769, -2101, 1611, -1830], [13133, -982, 629, 185, -615, -113, 2188], [14873, 794, 2151, -589, -4394, 3795, 1923], [-5100, 3904, 1998, -1270, 50, 5570, 180], [2506, -5408, -4168, 1554, -1005, 5326, 2111], [1611, -4458, 309, -1155, 240, 525, 1219], [3318, -116, 1301, -516, 2628, -5325, 66], [1044, -2192, 318, -506, 4468, -6222, -1798], [25441, 7242, 2975, 709, -1189, -1015, -2210], [-33390, 4746, -2700, 280, -3046, 3100, 1300], [7422, 1596, 62, -1222, -2450, -2766, -218], [13740, 4696, -243, -2330, -299, 6641, 1061], [-7310, -6476, 1106, 3534, 1290, 3614, -2326], [-4075, -11938, 1096, 5, 278, -1906, 1749], [-20183, -8194, -858, 359, -972, -884, -969], [4640, 216, -2062, -2812, 1200, -862, 34], [-3152, -5124, -4163, -522, -738, -437, 414], [-7774, -6790, -1052, 214, 1204, -728, 2150], [21316, -2572, 3064, -498, -1342, -808, 1012], [-2740, -5724, -4328, 372, 1364, 880, 1264], [19919, -2390, 6173, -1481, 345, 4367, -1186], [-15891, 1982, -3144, -2419, -927, 3696, -428], [14181, -10570, -4627, -239, 991, -1437, 888], [-8206, -4796, 1513, 504, -739, -2911, -1809], [-4872, -8284, 1054, -1516, 2405, -276, -1257], [18194, -8636, -861, 1684, 4000, -4299, -1590], [-16873, -80, -3463, 295, -105, -4021, -984], [16125, 1702, -1913, 55, 1774, -3869, 559], [6653, -446, -1001, -1919, 2879, -2903, 238], [-11190, 1224, -4808, -538, -1053, -1450, 2283], [-32850, -2888, -4090, -1816, 1150, 5134, -680], [2195, -3198, 3298, -369, -3686, 2488, 1475], [23441, -12518, -2283, -23, -2782, -3087, 995], [24420, -18962, -618, 482, 306, 446, -2414], [-25422, 2252, -6483, -1400, -2470, 4911, 1608], [-27654, -6544, 4684, -558, -2032, -1144, 2046], [6690, -8948, -2516, 942, -2352, 1384, 3158], [-25500, -4690, -1712, -704, -3230, 4420, -318], [13186, -4124, 4526, 222, 1816, -722, -126], [-19537, -3614, 458, -215, -10, 5192, -621], [13665, 7530, 3807, 33, -862, 839, 387], [-10419, -3466, -1134, -783, 2743, -4034, -174], [14637, -14898, -671, -23, -2955, 4099, -1776], [-15426, 8544, -678, -166, 1744, 2498, 1172], [18710, 13138, -2126, 488, 338, 5882, -556], [8272, 15304, 4332, 1564, -4064, 4500, 520], [13459, 12966, 68, -797, 3991, -860, -2968], [-17199, -4242, 803, -2479, 2483, 1409, -738], [5456, 208, -564, 3284, 696, -812, 772], [5348, -7344, -2443, -3182, -4231, 2289, 905], [-12323, 4974, 2889, -1115, 1908, 2049, -1923], [43595, -5206, -135, 429, 4168, -2335, 471], [35290, 548, -202, 654, -5424, 118, 1742], [-13915, 9162, 6184, 969, 3768, -2694, -2965], [18708, -4024, 3324, -560, -1830, -4984, 4854], [455, 8886, 3491, 1963, -2153, -191, 1168], [-4437, 10410, -1365, 699, 307, -575, -2392], [-33468, -2134, 4552, 2600, 788, -2840, 224], [24088, 7964, -3248, -1194, -2338, 3512, 1844], [21131, -16826, -4229, -1013, 3843, -5235, -988], [-5654, 3248, 386, -4330, 3206, -1050, -1706], [12122, 7362, 3992, 1224, 490, -4156, -200], [-32476, 7432, 3794, -530, 326, -3410, 194], [-6567, 5146, 3291, -297, 1240, -1741, 2473], [2116, 832, 2750, 1928, 438, 6, 1134], [26864, 108, 970, 3214, 1952, 1706, 742], [-9363, 2434, 1395, -2721, 7037, -4907, -2982], [42848, -2172, 1736, 56, -1992, 1040, 512], [24595, -9306, -3483, -261, 2881, -1405, 3302], [-15521, 3206, -1253, -3217, 491, 605, 1010], [-8252, 1502, -8520, 1308, 2018, -7740, 794], [37104, -4766, -1388, 1074, -1574, -180, 2794], [-9354, -948, -1879, -2258, -1804, 2999, 194], [2077, -7558, -7665, -4165, -943, 4245, 738], [30619, 3494, 2761, 379, -3418, -1867, -2571], [-32600, 792, 134, 1356, 1496, 594, 4308], [36816, -3284, -6424, 656, 1890, 580, -2088], [-30401, -5370, 4481, -597, -1473, 4663, -1186], [-1977, -5282, -756, -777, -3541, -1760, 1952], [-22060, -1904, 378, 2342, 1316, -3158, -786], [-17477, 11934, -914, -545, 1638, -11660, 115], [10542, 5342, -1616, -3674, -4696, -2220, 2842], [-19582, 3928, 4168, -54, -3402, 6024, 2476], [-21226, -3244, 1102, 3198, -1500, -3970, -1446], [30153, 6054, -2511, 3085, 1285, 5203, -50], [24184, 7016, 1376, -732, 398, -1796, -3252], [24082, 5860, -4426, 3130, -3852, -1314, 2466], [-5292, 13196, 3959, -2464, -130, 4153, -2510], [-36161, 3234, -5539, 1251, -203, -3633, 5014], [3872, -5256, -6997, 830, -2192, -6615, 1452], [-4873, 23922, -1967, -1021, -2587, -4769, 3072], [13656, 5992, -4438, 128, 3258, 2962, -4306], [-33711, 16090, 936, 565, -4001, 6964, -3198], [-3214, 3110, 4316, -2868, -112, 2016, 278], [15873, 9048, -1651, 781, -2231, 6839, 1740], [7581, 14770, 3615, 1017, 4661, -931, -2756], [-3186, -2536, -3086, -3336, -2118, 2210, -918], [7406, -1108, -4710, 1502, 2852, -3194, -1616], [-12811, -7594, 2372, -2887, 4214, 282, -339], [20309, 7378, -2879, -531, -2268, 9553, 1357], [24319, -24266, -2858, 683, -5364, 6060, -763], [-41150, 814, 2396, -298, -582, -2076, -488], [-43876, 15820, 2704, -278, 734, 5048, -3184], [35161, 3802, 7406, 2667, -3694, 6944, -2127], [2626, -7832, -4828, -300, 154, -6616, -4850], [20888, -12224, -1306, 2078, 1126, -7806, 2886], [15512, -4280, -4098, -3438, -760, -2522, -996], [-24582, -1330, 2080, 5080, -4016, -588, 2110], [27346, -13472, 1574, 1438, -2592, -1658, -5036], [-9727, -6238, -6808, -3473, 1134, 7598, -3675], [35514, -17500, 3342, 14, 2852, -2682, -2858], [17268, 10912, -4535, -1842, 6582, -2633, -2834], [5110, -9112, -2480, -3256, 1568, 1052, -8364], [-1693, 22178, 1207, -1281, 967, -4335, 3760], [-43932, 3720, -8252, 1006, 996, -4836, 698], [-40708, -22312, -1550, -3922, 7428, -894, 232], [2870, -5664, -856, 734, -2247, 538, 81], [24236, -13512, -7107, 1896, -78, -9109, 2034], [-35695, 5570, 6815, 1655, -465, -8527, -476], [14544, -10500, -4278, -2806, 2800, 42, 446], [9857, -13598, -1748, -4167, 5923, 1728, 1982], [29924, 14348, 303, -2196, 8472, -3291, -1116], [96421, 14562, 3125, 3829, -2865, 1935, -708], [-31331, -13094, -7130, -1339, -2640, 2160, -21], [23576, 19008, -680, -3860, 1512, 5360, 2048], [-64185, 5050, 1061, 237, -4161, 6351, 2094], [-2202, -14660, 1688, -2226, -6379, 4994, -907], [38666, 14404, -6081, -262, 1870, -3531, 1936], [62141, 9358, 1255, 2051, 1957, 13, -602], [-49722, -13172, -1286, -4250, 128, -7442, 756], [-86446, -13408, 312, -1476, 10, -6092, -704], [-24181, -6446, 7101, 117, -4878, -6295, 745], [81972, -9136, -3820, 1796, 4230, -368, -736], [-59090, -8028, -654, -658, -556, -11622, 3090], [10334, 5356, 133, -5880, 5910, 5699, -592], [-361, 7422, 5329, 4367, -3715, -5045, -5542], [-11038, -17520, -808, -5952, 1156, 200, -232], [-3091, -17626, 1065, 3237, -404, 8601, -3099], [17758, 1420, 5218, 106, -2184, 2642, 1060], [4168, 24672, -8388, -3328, -1552, 5356, 3400], [-10137, 29406, -4355, -5253, 541, 867, 6862], [-32340, -988, -6181, 948, -2774, 405, 2166], [-43187, 18702, -5744, -1531, -9082, 9006, 1317], [25899, -10250, 2889, 351, 1913, 4411, 1916], [9107, -11948, 4195, 4423, 8003, 3833, 392], [-20944, 25680, 3170, -38, 1812, 5050, 6130], [-43612, -11760, 3297, 2762, -7609, 6121, 5295], [-2838, 21598, 8092, -910, 5598, -2588, -6604], [18247, 24134, -2045, -1701, -3964, -9421, 3563], [-4657, 6558, 4341, 161, 1521, 7959, 4792], [18205, -2462, -8167, -5627, 5383, -4153, 2206], [28786, -4556, -4512, 6140, -3050, 11012, 1646], [42519, -18818, -2244, -4021, 332, -1170, 6845], [-68477, 7010, 6961, -3711, 3578, 3781, 1749], [37750, -4516, -584, 456, -8284, -8776, 2562], [12849, 9970, -3642, -387, 2393, -1618, 484], [12347, 7420, -1595, 3339, -5009, 5831, 4176], [-29552, 16048, 11234, -4696, 6580, -10730, -6432], [64535, -21198, -4299, 1097, -2487, 735, -3936], [40566, -23740, 5352, 2684, -3476, -2412, -6344], [8637, -13134, 9780, 5437, -4144, -8926, -3877], [112825, -1610, -1499, 1793, -3694, -1711, -2353], [28622, -9078, -50, -1524, 10042, -4586, -2824], [41827, 5098, 1234, 799, 2909, -6170, -1998], [89298, -9276, 486, 2590, -4112, -5370, -154], [7233, -2512, -11783, -5215, 4869, 787, -3028], [-83600, 868, -2377, 756, -2070, 3017, 1706], [-5238, -6988, -3444, -4718, 6793, -718, 321], [83058, -5632, -276, -2072, -3890, 296, 6178], [-35773, -6626, 713, 2051, 5215, 4439, -768], [15666, 10716, -1334, -1718, -9086, -8466, -5056], [-10008, -29928, 3428, 6406, -5710, -5244, -522], [13522, -28134, 3368, 1222, -1512, -2492, 1066], [97131, -15508, -2881, -1845, 3595, 4945, 6684], [24348, 9552, -3955, 2086, -3065, -1255, -4713], [59910, 6236, -1590, -4514, 5210, 8518, 1730], [-46261, -14534, 7908, -1573, -2236, -970, -3051], [-128827, 10014, 327, -2047, -1085, 7773, 138], [-95088, 3520, 6319, 1544, -1400, -5771, -212], [14873, 11270, -3765, 2615, -3277, 17341, 3524], [91501, 6258, -5481, -855, 4247, -3407, -346], [30241, 6478, -11081, -4947, -2094, 1807, 3115], [68826, -30624, -4517, 940, 3793, -16549, 143], [-4707, -5098, 820, 1453, -845, 16184, 1366], [26810, 29518, -10530, -6994, 92, 12142, 4674], [-47926, 6836, -9890, 346, 6208, -7246, -1192], [91470, 6284, -10160, -4608, 3820, -13024, 188], [25828, 48, -5746, -4002, -4400, -11882, -866], [57237, 28922, 10453, 1913, -8580, 8917, -3595], [3966, 1600, -5856, -6770, 5858, -1616, 1068], [-11721, -2884, 6491, -2649, -3157, 5881, -1412], [-56282, 26028, -9712, -1586, 4440, -4476, 4750], [-87590, 4916, 3837, 110, -11654, 13735, 764], [-5475, 14130, 6622, -9275, 7436, 6964, -3953], [58660, -7044, 5330, 3904, -4345, -9752, -2287], [30140, 18464, 222, -2648, -5214, -2458, -2646], [-26561, 9358, -9907, 751, -11379, 7815, 6618], [-30312, 30532, -3048, 352, 6156, -18544, 4982], [-11346, -7936, -7138, -7866, 268, -9050, 7380], [-19500, 10472, -7485, 2614, 917, -3941, 2749], [4770, 17156, 8478, 11454, -6032, -2018, -1710], [-57635, -27450, 7134, -8123, 8675, -4562, -2946], [3745, 12786, 995, -3609, 1635, -935, -1564], [-13372, -25240, -8116, 1272, -9548, 3460, 56], [33239, -610, -2507, 4147, 654, 5301, 3769], [15685, 19686, 2015, 497, -4577, 19333, 5062], [-50647, 12334, 2607, -1345, -707, -2679, 2030], [14444, 9416, 5730, -4450, -1136, -2018, -3634], [32276, 2498, 2146, -4406, -10466, 14534, 1394], [39474, 27768, -1470, -4364, -3504, 14054, 6766], [24605, -16286, -7627, 2201, 1572, -15987, 941], [24726, -2660, -10528, -3438, 2096, 2552, -2860], [-230, 13220, -2754, -502, 3544, -4746, 3358], [56332, -21328, -5858, 1380, 5961, 3016, -529], [45176, -4576, -6126, -3084, 11957, -8908, -2245], [-36180, -15904, 11116, -2972, -2248, -4724, -5672], [-4722, 20284, -6592, -2006, -1334, -664, 132], [15779, 12614, 721, 5833, -7327, 179, 864], [-99688, -7332, 88, 2644, 3198, 5492, -324], [8577, 11938, -882, -9625, 3486, -2360, 8165], [-40232, 264, -11930, -9640, 3380, 7218, 1000], [85112, -19546, 3632, 218, 3346, 10156, 1990], [68403, -12434, -4051, -1647, 609, -5369, 6100], [37455, -3054, 9280, -1641, 655, -608, 7048], [-83256, 28544, 8541, -1762, 4235, -439, -5129], [-20183, 1104, 4159, -2543, -5221, 8813, -1494], [-79024, -32172, 4512, 988, 4664, 1568, 2372], [48218, 13996, 1134, 3310, -2364, 10970, 4164], [15466, 8202, 4792, 590, 7300, 9500, -434], [82972, 8528, -4784, -4780, 5128, -2604, -3644], [74007, 25394, 7726, 5999, -5980, 15840, 3425], [-12929, -4514, 3525, -3171, -10205, 855, 1014], [104040, 20972, -5588, -4744, -9792, -7772, 2030], [-63911, 2966, -11530, -2075, -2642, -12592, 2721], [-62270, 19932, -8060, 7442, -9257, 2410, -6589], [-28975, -15110, -4701, 4813, 11725, 937, 9164], [-3444, 20472, -3397, -3374, 7826, 4041, -2898]]
